@@ -3,8 +3,9 @@ from __future__ import annotations
 import contextlib
 import functools
 import json
-import typing
 import uuid
+from collections.abc import AsyncGenerator, AsyncIterator, Callable, Generator
+from typing import TypedDict
 
 import pytest
 
@@ -165,7 +166,7 @@ app = Router(
 @pytest.fixture
 def client(
     test_client_factory: TestClientFactory,
-) -> typing.Generator[TestClient, None, None]:
+) -> Generator[TestClient, None, None]:
     with test_client_factory(app) as client:
         yield client
 
@@ -586,7 +587,7 @@ def test_standalone_route_matches(
 
 
 def test_standalone_route_does_not_match(
-    test_client_factory: typing.Callable[..., TestClient],
+    test_client_factory: Callable[..., TestClient],
 ) -> None:
     app = Route("/", PlainTextResponse("Hello, World!"))
     client = test_client_factory(app)
@@ -659,7 +660,7 @@ def test_lifespan_with_on_events(test_client_factory: TestClientFactory) -> None
     shutdown_called = False
 
     @contextlib.asynccontextmanager
-    async def lifespan(app: Starlette) -> typing.AsyncGenerator[None, None]:
+    async def lifespan(app: Starlette) -> AsyncGenerator[None, None]:
         nonlocal lifespan_called
         lifespan_called = True
         yield
@@ -731,7 +732,7 @@ def test_lifespan_state_unsupported(
     @contextlib.asynccontextmanager
     async def lifespan(
         app: ASGIApp,
-    ) -> typing.AsyncGenerator[dict[str, str], None]:
+    ) -> AsyncGenerator[dict[str, str], None]:
         yield {"foo": "bar"}
 
     app = Router(
@@ -752,7 +753,7 @@ def test_lifespan_state_async_cm(test_client_factory: TestClientFactory) -> None
     startup_complete = False
     shutdown_complete = False
 
-    class State(typing.TypedDict):
+    class State(TypedDict):
         count: int
         items: list[int]
 
@@ -767,7 +768,7 @@ def test_lifespan_state_async_cm(test_client_factory: TestClientFactory) -> None
         return PlainTextResponse("hello, world")
 
     @contextlib.asynccontextmanager
-    async def lifespan(app: Starlette) -> typing.AsyncIterator[State]:
+    async def lifespan(app: Starlette) -> AsyncIterator[State]:
         nonlocal startup_complete, shutdown_complete
         startup_complete = True
         state = State(count=0, items=[])
@@ -896,7 +897,7 @@ class Endpoint:
         pytest.param(lambda request: ..., "<lambda>", id="lambda"),  # pragma: no branch
     ],
 )
-def test_route_name(endpoint: typing.Callable[..., Response], expected_name: str) -> None:
+def test_route_name(endpoint: Callable[..., Response], expected_name: str) -> None:
     assert Route(path="/", endpoint=endpoint).name == expected_name
 
 
@@ -1005,7 +1006,7 @@ def test_mount_asgi_app_with_middleware_url_path_for() -> None:
 
 
 def test_add_route_to_app_after_mount(
-    test_client_factory: typing.Callable[..., TestClient],
+    test_client_factory: Callable[..., TestClient],
 ) -> None:
     """Checks that Mount will pick up routes
     added to the underlying app after it is mounted
@@ -1038,9 +1039,9 @@ def test_exception_on_mounted_apps(
 
 
 def test_mounted_middleware_does_not_catch_exception(
-    test_client_factory: typing.Callable[..., TestClient],
+    test_client_factory: Callable[..., TestClient],
 ) -> None:
-    # https://github.com/encode/starlette/pull/1649#discussion_r960236107
+    # https://github.com/Kludex/starlette/pull/1649#discussion_r960236107
     def exc(request: Request) -> Response:
         raise HTTPException(status_code=403, detail="auth")
 
